@@ -6,9 +6,10 @@ class MyFile(pytest.File):
         return [MyItem.from_parent(name="hello", parent=self)]
 
 
-def pytest_collect_file(path, parent):
-    return MyFile.from_parent(fspath=path, parent=parent)
+def pytest_collect_file(file_path, parent):
+    return MyFile.from_parent(path=file_path, parent=parent)
 
 
 class MyItem(pytest.Item):
-    pass
+    def runtest(self):
+        raise NotImplementedError()
