@@ -1,10 +1,12 @@
 """Issue #7110"""
+
 import asyncio
+from typing import List
 
 import asynctest
 
 
-teardowns = []
+teardowns: List[None] = []
 
 
 class Test(asynctest.TestCase):
