@@ -1,10 +1,10 @@
-"""
-Generates an executable with pytest runner embedded using PyInstaller.
-"""
+"""Generate an executable with pytest runner embedded using PyInstaller."""
+
 if __name__ == "__main__":
-    import pytest
     import subprocess
 
+    import pytest
+
     hidden = []
     for x in pytest.freeze_includes():
         hidden.extend(["--hidden-import", x])
