@@ -1,7 +1,7 @@
-import os
-import platform
 from datetime import datetime
+import os
 from pathlib import Path
+import platform
 from typing import cast
 from typing import List
 from typing import Optional
@@ -12,7 +12,6 @@ from xml.dom import minidom
 
 import xmlschema
 
-import pytest
 from _pytest.config import Config
 from _pytest.junitxml import bin_xml_escape
 from _pytest.junitxml import LogXML
@@ -22,6 +21,7 @@ from _pytest.pytester import RunResult
 from _pytest.reports import BaseReport
 from _pytest.reports import TestReport
 from _pytest.stash import Stash
+import pytest
 
 
 @pytest.fixture(scope="session")
@@ -1282,12 +1282,10 @@ def test_record_fixtures_without_junitxml(
     pytester: Pytester, fixture_name: str
 ) -> None:
     pytester.makepyfile(
-        """
+        f"""
         def test_record({fixture_name}):
             {fixture_name}("foo", "bar")
-    """.format(
-            fixture_name=fixture_name
-        )
+    """
     )
     result = pytester.runpytest()
     assert result.ret == 0
@@ -1335,7 +1333,7 @@ def test_record_fixtures_xunit2(
     """
     )
     pytester.makepyfile(
-        """
+        f"""
         import pytest
 
         @pytest.fixture
@@ -1343,9 +1341,7 @@ def test_record_fixtures_xunit2(
             {fixture_name}("bar", 1)
         def test_record({fixture_name}, other):
             {fixture_name}("foo", "<1");
-    """.format(
-            fixture_name=fixture_name
-        )
+    """
     )
 
     result, dom = run_and_parse(family=None)
@@ -1355,10 +1351,8 @@ def test_record_fixtures_xunit2(
             "*test_record_fixtures_xunit2.py:6:*record_xml_attribute is an experimental feature"
         )
     expected_lines = [
-        "*test_record_fixtures_xunit2.py:6:*{fixture_name} is incompatible "
-        "with junit_family 'xunit2' (use 'legacy' or 'xunit1')".format(
-            fixture_name=fixture_name
-        )
+        f"*test_record_fixtures_xunit2.py:6:*{fixture_name} is incompatible "
+        "with junit_family 'xunit2' (use 'legacy' or 'xunit1')"
     ]
     result.stdout.fnmatch_lines(expected_lines)
 
@@ -1610,13 +1604,11 @@ def test_set_suite_name(
 ) -> None:
     if suite_name:
         pytester.makeini(
-            """
+            f"""
             [pytest]
             junit_suite_name={suite_name}
-            junit_family={family}
-        """.format(
-                suite_name=suite_name, family=xunit_family
-            )
+            junit_family={xunit_family}
+        """
         )
         expected = suite_name
     else:
@@ -1697,14 +1689,12 @@ def test_logging_passing_tests_disabled_does_not_log_test_output(
     pytester: Pytester, run_and_parse: RunAndParse, xunit_family: str
 ) -> None:
     pytester.makeini(
-        """
+        f"""
         [pytest]
         junit_log_passing_tests=False
         junit_logging=system-out
-        junit_family={family}
-    """.format(
-            family=xunit_family
-        )
+        junit_family={xunit_family}
+    """
     )
     pytester.makepyfile(
         """
@@ -1734,13 +1724,11 @@ def test_logging_passing_tests_disabled_logs_output_for_failing_test_issue5430(
     xunit_family: str,
 ) -> None:
     pytester.makeini(
-        """
+        f"""
         [pytest]
         junit_log_passing_tests=False
-        junit_family={family}
-    """.format(
-            family=xunit_family
-        )
+        junit_family={xunit_family}
+    """
     )
     pytester.makepyfile(
         """
