@@ -5,16 +5,16 @@ import time
 from types import ModuleType
 from typing import List
 
-import _pytest.pytester as pytester_mod
-import pytest
 from _pytest.config import ExitCode
 from _pytest.config import PytestPluginManager
 from _pytest.monkeypatch import MonkeyPatch
+import _pytest.pytester as pytester_mod
 from _pytest.pytester import HookRecorder
 from _pytest.pytester import LineMatcher
 from _pytest.pytester import Pytester
 from _pytest.pytester import SysModulesSnapshot
 from _pytest.pytester import SysPathsSnapshot
+import pytest
 
 
 def test_make_hook_recorder(pytester: Pytester) -> None:
@@ -704,15 +704,13 @@ def test_spawn_uses_tmphome(pytester: Pytester) -> None:
     pytester._monkeypatch.setenv("CUSTOMENV", "42")
 
     p1 = pytester.makepyfile(
-        """
+        f"""
         import os
 
         def test():
             assert os.environ["HOME"] == {tmphome!r}
             assert os.environ["CUSTOMENV"] == "42"
-        """.format(
-            tmphome=tmphome
-        )
+        """
     )
     child = pytester.spawn_pytest(str(p1))
     out = child.read()
