@@ -1,7 +1,6 @@
 from typing import Sequence
 from typing import Union
 
-import pytest
 from _pytest._code.code import ExceptionChainRepr
 from _pytest._code.code import ExceptionRepr
 from _pytest.config import Config
@@ -9,6 +8,7 @@ from _pytest.pytester import Pytester
 from _pytest.python_api import approx
 from _pytest.reports import CollectReport
 from _pytest.reports import TestReport
+import pytest
 
 
 class TestReportSerialization:
@@ -278,7 +278,7 @@ class TestReportSerialization:
     ) -> None:
         """Check serialization/deserialization of report objects containing chained exceptions (#5786)"""
         pytester.makepyfile(
-            """
+            f"""
             def foo():
                 raise ValueError('value error')
             def test_a():
@@ -286,11 +286,9 @@ class TestReportSerialization:
                     foo()
                 except ValueError as e:
                     raise RuntimeError('runtime error') from e
-            if {error_during_import}:
+            if {report_class is CollectReport}:
                 test_a()
-        """.format(
-                error_during_import=report_class is CollectReport
-            )
+        """
         )
 
         reprec = pytester.inline_run()
