@@ -1,15 +1,14 @@
+from functools import partial
 import inspect
 import os
+from pathlib import Path
 import sys
 import types
-from functools import partial
-from pathlib import Path
 from typing import Dict
 from typing import List
 from typing import Tuple
 from typing import Type
 
-import pytest
 from _pytest import outcomes
 from _pytest import reports
 from _pytest import runner
@@ -19,6 +18,8 @@ from _pytest.config import ExitCode
 from _pytest.monkeypatch import MonkeyPatch
 from _pytest.outcomes import OutcomeException
 from _pytest.pytester import Pytester
+import pytest
+
 
 if sys.version_info[:2] < (3, 11):
     from exceptiongroup import ExceptionGroup
@@ -1087,53 +1088,3 @@ def test_outcome_exception_bad_msg() -> None:
     with pytest.raises(TypeError) as excinfo:
         OutcomeException(func)  # type: ignore
     assert str(excinfo.value) == expected
-
-
-def test_teardown_session_failed(pytester: Pytester) -> None:
-    """Test that higher-scoped fixture teardowns run in the context of the last
-    item after the test session bails early due to --maxfail.
-
-    Regression test for #11706.
-    """
-    pytester.makepyfile(
-        """
-        import pytest
-
-        @pytest.fixture(scope="module")
-        def baz():
-            yield
-            pytest.fail("This is a failing teardown")
-
-        def test_foo(baz):
-            pytest.fail("This is a failing test")
-
-        def test_bar(): pass
-        """
-    )
-    result = pytester.runpytest("--maxfail=1")
-    result.assert_outcomes(failed=1, errors=1)
-
-
-def test_teardown_session_stopped(pytester: Pytester) -> None:
-    """Test that higher-scoped fixture teardowns run in the context of the last
-    item after the test session bails early due to --stepwise.
-
-    Regression test for #11706.
-    """
-    pytester.makepyfile(
-        """
-        import pytest
-
-        @pytest.fixture(scope="module")
-        def baz():
-            yield
-            pytest.fail("This is a failing teardown")
-
-        def test_foo(baz):
-            pytest.fail("This is a failing test")
-
-        def test_bar(): pass
-        """
-    )
-    result = pytester.runpytest("--stepwise")
-    result.assert_outcomes(failed=1, errors=1)
